pub struct LineClamp {
pub max_lines: u16,
}Expand description
Line clamp configuration.
Limits the number of visible lines, truncating with an ellipsis on the last visible line when content exceeds the limit.
Fields
max_lines: u16Maximum number of visible lines. 0 means unlimited.
Implementations