StyleFlags

Struct StyleFlags 

#[repr(transparent)]
pub struct StyleFlags(pub u16);
Text attribute flags (16 bits for extended attribute support).

These flags represent visual attributes that can be applied to text. Using u16 allows for additional underline variants beyond basic SGR.

Tuple Fields

0: u16

Implementations

Source

impl StyleFlags

pub const NONE: Self

No attributes set.

pub const BOLD: Self

Bold / increased intensity.

pub const DIM: Self

Dim / decreased intensity.

pub const ITALIC: Self

Italic text.

pub const UNDERLINE: Self

Single underline.

Blinking text.

pub const REVERSE: Self

Reverse video (swap fg/bg).

pub const HIDDEN: Self

Hidden / invisible text.

pub const STRIKETHROUGH: Self

Strikethrough text.

pub const DOUBLE_UNDERLINE: Self

Double underline (extended attribute).

pub const CURLY_UNDERLINE: Self

Curly / wavy underline (extended attribute).

pub const fn contains(self, other: Self) -> bool

Check if this flags set contains another flags set.

pub fn insert(&mut self, other: Self)

Insert flags into this set.

pub fn remove(&mut self, other: Self)

Remove flags from this set.

pub const fn is_empty(self) -> bool

Check if the flags set is empty.

pub const fn union(self, other: Self) -> Self

Combine two flag sets (OR operation).