pub struct Gradient { /* private fields */ }Expand description
A multi-stop gradient for table effects.
Implementations
Sourceimpl Gradient
impl Gradient
Sourcepub fn new(stops: Vec<(f32, PackedRgba)>) -> Self
pub fn new(stops: Vec<(f32, PackedRgba)>) -> Self
Create a new gradient with stops in the range [0, 1].
Sourcepub fn stops(&self) -> &[(f32, PackedRgba)]
pub fn stops(&self) -> &[(f32, PackedRgba)]
Access the gradient stops (sorted by position).
Sourcepub fn sample(&self, t: f32) -> PackedRgba
pub fn sample(&self, t: f32) -> PackedRgba
Sample the gradient at a normalized position in [0, 1].